# Redfin Scraper

## Description
A Python library used to scrape data from Redfin.com using the unofficial Stringray API.

Please note that certain cities/zip codes may not be available pursuant to the bylaws of the MLS for that jurisdiction.

This library is **powerful**, and if not used properly, can result in:
* Consumption of all available CPU resources for an extended period of time
* Discipinary action from Redfin against your IP address

## Installation
`pip install redfin-scraper`

## Usage
See the wiki.
